<?php
/**
 * Envato Theme Setup Wizard Class
 *
 * Takes new users through some basic steps to setup their ThemeForest theme.
 *
 * @author      strictthemes
 * @author      dtbaker
 * @author      vburlak
 * @package     envato_wizard
 * @version     1.1.4
 *
 * Based off the WooThemes installer.
 *
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Envato_Theme_Setup_Wizard' ) ) {

	class Envato_Theme_Setup_Wizard {

		protected $version = '1.1.4';

		protected $theme_name = '';

		protected $envato_username = '';

		protected $oauth_script = '';

		protected $step = '';

		protected $steps = array();

		protected $plugin_path = '';

		protected $plugin_url = '';

		protected $page_slug;

		protected $tgmpa_instance;

		protected $tgmpa_menu_slug = 'tgmpa-install-plugins';

		protected $tgmpa_url = 'themes.php?page=tgmpa-install-plugins';

		protected $page_parent;

		protected $page_url;

		private static $instance = null;

		public static function get_instance() {
			if ( ! self::$instance ) {
				self::$instance = new self;
			}
			return self::$instance;
		}

		public function __construct() {
			$this->init_globals();
			$this->init_actions();
		}

		// Setup the class globals.
		public function init_globals() {
			$current_theme = wp_get_theme();
			$this->theme_name = strtolower( preg_replace( '#[^a-zA-Z]#','',$current_theme->get( 'Name' ) ) );
			$this->envato_username = apply_filters( $this->theme_name . '_theme_setup_wizard_username', 'strictthemes' );
			$this->oauth_script = apply_filters( $this->theme_name . '_theme_setup_wizard_oauth_script', 'http://dtbaker.net/files/envato/wptoken/server-script.php' );
			$this->page_slug = apply_filters( $this->theme_name . '_theme_setup_wizard_page_slug', $this->theme_name.'-setup' );
			$this->parent_slug = apply_filters( $this->theme_name . '_theme_setup_wizard_parent_slug', '' );

			// If we have parent slug - set correct url
			if ( $this->parent_slug !== '' ) {
				$this->page_url = 'admin.php?page='.$this->page_slug;
			} else {
				$this->page_url = 'themes.php?page='.$this->page_slug;
			}
			$this->page_url = apply_filters( $this->theme_name . '_theme_setup_wizard_page_url', $this->page_url );

			// ST
			$this->plugin_url = plugins_url() . '/stkit/components/demo_setup';
		}

		public function init_actions() {

			if ( apply_filters( $this->theme_name . '_enable_setup_wizard', true ) && current_user_can( 'manage_options' )  ) {

				if (class_exists( 'TGM_Plugin_Activation' ) && isset($GLOBALS['tgmpa'])) {
					add_action( 'init', array( $this, 'get_tgmpa_instanse' ), 30 );
					add_action( 'init', array( $this, 'set_tgmpa_url' ), 40 );
				}

				add_action( 'admin_menu', array( $this, 'admin_menus' ) );
				add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
				add_action( 'admin_init', array( $this, 'admin_redirects' ), 30 );
				add_action( 'admin_init', array( $this, 'init_wizard_steps' ), 30 );
				add_action( 'admin_init', array( $this, 'setup_wizard' ), 30 );
				add_filter( 'tgmpa_load', array( $this, 'tgmpa_load' ), 10, 1 );
				add_action( 'wp_ajax_envato_setup_plugins', array( $this, 'ajax_plugins' ) );
				add_action( 'wp_ajax_envato_setup_content', array( $this, 'ajax_content' ) );
			}

		}

		public function enqueue_scripts() {
		}

		public function tgmpa_load( $status ) {
			return is_admin() || current_user_can( 'install_themes' );
		}

		public function switch_theme() {
			set_transient( '_'.$this->theme_name.'_activation_redirect', 1 );
		}

		public function admin_redirects() {
			ob_start();
			if ( ! get_transient( '_'.$this->theme_name.'_activation_redirect' ) ) {
				return;
			}
			delete_transient( '_'.$this->theme_name.'_activation_redirect' );
			wp_safe_redirect( admin_url( $this->page_url ) );
			exit;
		}

		public function get_tgmpa_instanse(){
			$this->tgmpa_instance = call_user_func( array( get_class( $GLOBALS['tgmpa'] ), 'get_instance' ) );
		}

		public function set_tgmpa_url(){

			$this->tgmpa_menu_slug = ( property_exists($this->tgmpa_instance, 'menu') ) ? $this->tgmpa_instance->menu : $this->tgmpa_menu_slug;
			$this->tgmpa_menu_slug = apply_filters($this->theme_name . '_theme_setup_wizard_tgmpa_menu_slug', $this->tgmpa_menu_slug);

			$tgmpa_parent_slug = ( property_exists($this->tgmpa_instance, 'parent_slug') && $this->tgmpa_instance->parent_slug !== 'themes.php' ) ? 'admin.php' : 'themes.php';

			$this->tgmpa_url = apply_filters($this->theme_name . '_theme_setup_wizard_tgmpa_url', $tgmpa_parent_slug.'?page='.$this->tgmpa_menu_slug);

		}

		// Add admin menus/screens.
		public function admin_menus() {

			if ( $this->is_submenu_page() ){
				// prevent Theme Check warning about "themes should use add_theme_page for adding admin pages"
				$add_subpage_function = 'add_submenu'.'_page';
				$add_subpage_function( $this->parent_slug, esc_attr__( 'Setup Wizard','stkit' ), esc_attr__( 'Setup Wizard','stkit' ), 'manage_options', $this->page_slug, array( $this, 'setup_wizard' ) );
			} else {
				// add_theme_page( esc_attr__( 'Setup Wizard','stkit' ), esc_attr__( 'Setup Wizard','stkit' ), 'manage_options', $this->page_slug, array( $this, 'setup_wizard' ) );
				add_submenu_page ( 'st-major-settings', esc_html__( 'Setup Wizard', 'stkit' ), esc_html__( 'Setup Wizard', 'stkit' ), 'edit_theme_options', $this->page_slug, array( $this, 'setup_wizard' ) );
			}

		}

		// Setup steps
		public function init_wizard_steps() {

			$this->steps = array(
				'introduction' => array(
					'name'    => esc_attr__( 'Introduction', 'stkit' ),
					'view'    => array( $this, 'envato_setup_introduction' ),
					'handler' => '',
				),
			);
			$this->steps['theme_settings'] = array(
				'name'    => esc_attr__( 'Theme Settings', 'stkit' ),
				'view'    => array( $this, 'envato_setup_theme_settings' ),
				'handler' => array( $this, 'envato_setup_theme_settings_save' ),
			);
			$this->steps['default_content'] = array(
				'name'    => esc_attr__( 'Content', 'stkit' ),
				'view'    => array( $this, 'envato_setup_default_content' ),
				'handler' => '',
			);
			$this->steps['help_support'] = array(
				'name'    => esc_attr__( 'Assistance', 'stkit' ),
				'view'    => array( $this, 'envato_setup_help_support' ),
				'handler' => '',
			);
			$this->steps['next_steps'] = array(
				'name'    => esc_attr__( 'Ready!', 'stkit' ),
				'view'    => array( $this, 'envato_setup_ready' ),
				'handler' => '',
			);

			return apply_filters(  $this->theme_name . '_theme_setup_wizard_steps', $this->steps );

		}

		// Show the setup wizard
		public function setup_wizard() {

			if ( empty( $_GET['page'] ) || $this->page_slug !== $_GET['page'] ) {
				return;
			}
			ob_end_clean();

			$this->step = isset( $_GET['step'] ) ? sanitize_key( $_GET['step'] ) : current( array_keys( $this->steps ) );

			wp_register_script( 'jquery-blockui', $this->plugin_url . '/js/jquery.blockUI.js', array( 'jquery' ), '2.70', true );
			wp_register_script( 'envato-setup', $this->plugin_url . '/js/envato-setup.js', array( 'jquery', 'jquery-blockui' ), $this->version );
			wp_localize_script( 'envato-setup', 'envato_setup_params', array(
				'tgm_plugin_nonce'            => array(
					'update' => wp_create_nonce( 'tgmpa-update' ),
					'install' => wp_create_nonce( 'tgmpa-install' ),
				),
				'tgm_bulk_url' => admin_url( $this->tgmpa_url ),
				'ajaxurl' => admin_url( 'admin-ajax.php' ),
				'wpnonce' => wp_create_nonce( 'envato_setup_nonce' ),
				'verify_text' => esc_attr__( '...verifying','stkit' ),
			) );

			wp_enqueue_style( 'envato-setup', $this->plugin_url . '/css/demo-setup.css', array( 'dashicons', 'install' ), $this->version );

			//enqueue style for admin notices
			wp_enqueue_style( 'wp-admin' );

			wp_enqueue_media();
			wp_enqueue_script( 'media' );

			ob_start();
			$this->setup_wizard_header();
			$this->setup_wizard_steps();
			$show_content = true;
			echo '<div class="envato-setup-content">';
			if ( ! empty( $_REQUEST['save_step'] ) && isset( $this->steps[ $this->step ]['handler'] ) ) {
				$show_content = call_user_func( $this->steps[ $this->step ]['handler'] );
			}
			if ( $show_content ) {
				$this->setup_wizard_content();
			}
			echo '</div>';
			$this->setup_wizard_footer();
			exit;

		}

		public function get_step_link( $step ) {
			return  add_query_arg( 'step', $step, admin_url( 'admin.php?page=' . $this->page_slug ) );
		}

		public function get_next_step_link() {
			$keys = array_keys( $this->steps );
			return add_query_arg( 'step', $keys[ array_search( $this->step, array_keys( $this->steps ) ) + 1 ], remove_query_arg( 'translation_updated' ) );
		}

		// Setup Wizard Header
		public function setup_wizard_header() {
			?><!DOCTYPE html>
				<html xmlns="http://www.w3.org/1999/xhtml" <?php language_attributes(); ?>>
				<head>
					<meta name="viewport" content="width=device-width" />
					<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
					<title><?php esc_attr_e( 'Theme &rsaquo; Setup Wizard', 'stkit' ); ?></title>
					<?php wp_print_scripts( 'envato-setup' ); ?>
					<?php do_action( 'admin_print_styles' ); ?>
					<?php do_action( 'admin_print_scripts' ); ?>
					<?php do_action( 'admin_head' ); ?>
				</head>
				<body class="envato-setup wp-core-ui">
				<h1 id="wc-logo">
					<a href="http://strictthemes.com/to/portfolio" target="_blank"><?php
						$image_url = get_theme_mod( 'logo_header_image', get_template_directory_uri() . '/demo/logo.png' );
						if ( $image_url ) {
							$image = '<img class="site-logo" src="%s" alt="" />';
							printf(
								$image,
								$image_url,
								get_bloginfo( 'name' ),
								'200px'
							);
						} else { ?>
							<img src="<?php echo $this->plugin_url; ?>/images/logo.png" alt="" /><?php
						} ?></a>
				</h1>
			<?php
		}

		// Setup Wizard Footer
		public function setup_wizard_footer() {
			if ( 'next_steps' === $this->step ) : ?>
				<a class="wc-return-to-dashboard" href="<?php echo esc_url( admin_url() ); ?>"><?php esc_attr_e( 'Return to the WordPress Dashboard', 'stkit' ); ?></a><?php
			endif; ?>
			</body>
			<?php
				@do_action( 'admin_footer' ); // this was spitting out some errors in some admin templates. quick @ fix until I have time to find out what's causing errors.
				do_action( 'admin_print_footer_scripts' );
			?>
			</html><?php
		}

		// Output the steps
		public function setup_wizard_steps() {

			$ouput_steps = $this->steps;
			array_shift( $ouput_steps );
			?>
				<ol class="envato-setup-steps">
					<?php foreach ( $ouput_steps as $step_key => $step ) : ?>
						<li class="<?php
						$show_link = false;
						if ( $step_key === $this->step ) {
							echo 'active';
						} elseif ( array_search( $this->step, array_keys( $this->steps ) ) > array_search( $step_key, array_keys( $this->steps ) ) ) {
							echo 'done';
							$show_link = true;
						}
						?>"><?php
							if ( $show_link ) {
								?>
								<a href="<?php echo esc_url( $this->get_step_link( $step_key ) );?>"><?php echo esc_html( $step['name'] );?></a>
								<?php
							} else {
								echo esc_html( $step['name'] );
							}
							?></li>
					<?php endforeach; ?>
				</ol>
			<?php
		}

		// Output the content for the current step
		public function setup_wizard_content() {
			isset( $this->steps[ $this->step ] ) ? call_user_func( $this->steps[ $this->step ]['view'] ) : false;
		}



	/*= 0 ============================================
	
		I N T R O D U C T I O N
		Step
	
	===============================================*/

		public function envato_setup_introduction() {

		/*-------------------------------------------
			Export
		-------------------------------------------*/

			if ( isset( $_REQUEST['export'] ) ) {

				global
					$wpdb,
					$st_Options,
					$st_Settings;

				// Get widget positions
				$widget_positions = get_option( 'sidebars_widgets' );

				// Get widget options
				$widget_options = array();
				$my_options = array();
				foreach ( $widget_positions as $sidebar_name => $widgets ) {
					if ( is_array( $widgets ) ) {
						foreach ( $widgets as $widget_name ) {
							$widget_name_strip = preg_replace( '#-\d+$#', '', $widget_name );
							$widget_options[ $widget_name_strip ] = get_option( 'widget_' . $widget_name_strip );
						}
					}
				}

				// Get category options
				$st_['categories'] = get_categories();
				$category_options = array();
				foreach( $st_['categories'] as $st_['category'] ) {

					$st_['att_id'] = get_option( 'st_category_image_' . $st_['category']->term_id );
					if ( $st_['att_id'] )
						$category_options[$st_['category']->term_id]['image'] = $st_['att_id'];

					$st_['sidebar_id'] = get_option( 'st_category_sidebar_' . $st_['category']->term_id );
					if ( $st_['sidebar_id'] )
						$category_options[$st_['category']->term_id]['sidebar'] = $st_['sidebar_id'];

				}

				?>

					<h1>Export</h1>
	
					<div id="export-settings">

						<p>theme-settings.txt</p>
						<textarea style="width:100%; height:80px;"><?php
							if ( isset( $_REQUEST['raw'] ) )
								print_r( $st_Settings );
							else
								echo base64_encode( serialize( ( $st_Settings ) ) )
						?></textarea>

						<p>widget-options.txt</p>
						<textarea style="width:100%; height:80px;"><?php
							if ( isset( $_REQUEST['raw'] ) )
								print_r( $widget_options );
							else
								echo base64_encode( serialize( $widget_options ) )
						?></textarea>

						<p>widget-positions.txt</p>
						<textarea style="width:100%; height:80px;"><?php
							if ( isset( $_REQUEST['raw'] ) )
								print_r( $widget_positions );
							else
								echo base64_encode( serialize( $widget_positions ) );
						?></textarea>

						<p>category-options.txt</p>
						<textarea style="width:100%; height:80px;"><?php
							if ( isset( $_REQUEST['raw'] ) )
								print_r( $category_options );
							else
								echo base64_encode( serialize( $category_options ) );
						?></textarea>

						<?php
				
							// Options options
							foreach ( $st_Options['global']['demo']['options'] as $st_['option'] ) {
		
								echo '<p>option-' . $st_['option'] . '.txt</p>'; ?>
								<textarea style="width:100%; height:80px;"><?php echo base64_encode( serialize( ( get_option( $st_['option'] ) ) ) )?></textarea><?php
				
							}
						?>

					</div>

				<?php

			}

		/*-------------------------------------------
			Output: Introduction
		-------------------------------------------*/

			else {
				?>
				<h1><?php esc_attr_e( 'Welcome to Setup Wizard' ); ?></h1>
				<p><?php esc_attr_e( 'This quick Setup Wizard will help you configure your new website. The Wizard will install theme settings, default content, logo, menus, widgets and tell you a little about Help &amp; Support options. It should only take 5-10 minutes.' ); ?></p>
				<p><?php esc_attr_e( 'No time right now? If you don\'t want to go through the wizard, you can skip and return to the WordPress dashboard. Come back anytime if you change your mind!' ); ?></p>
				<p class="envato-setup-actions step">
					<a href="<?php echo esc_url( $this->get_next_step_link() ); ?>" class="button-primary button button-large button-next"><?php esc_attr_e( "Let's Go!" ); ?></a>
					<a href="<?php echo esc_url( wp_get_referer() && ! strpos( wp_get_referer(),'update.php' ) ? wp_get_referer() : admin_url( '' ) ); ?>" class="button button-large"><?php esc_attr_e( 'Not right now' ); ?></a>
				</p>
				<?php
			}
		}



	/*= 1 ============================================
	
		T H E M E   S E T T I N G S
		Step
	
	===============================================*/

		public function envato_setup_theme_settings() {

			// Check a file
			if ( file_exists( get_stylesheet_directory() . '/demo/theme-settings.txt' ) )
				$st_['theme_settings_file'] = get_stylesheet_directory() . '/demo/theme-settings.txt';

			elseif ( file_exists( get_template_directory() . '/demo/theme-settings.txt' ) )
				$st_['theme_settings_file'] = get_template_directory() . '/demo/theme-settings.txt';

			?>
			<h1><?php esc_attr_e( 'Theme Settings', 'stkit' ); ?></h1>
			<form method="post">
				<?php echo '<p>' . esc_attr__( "In first we need to define a default options for Theme Panel. Such options will activate a required settings for importing process. Let's do this.", 'stkit' ) . '</p>'; ?>

				<?php
					if ( empty( $st_['theme_settings_file'] ) )
						echo '<div class="notice-warning notice">' . esc_attr__( "The theme-settings.txt file doesn't exist in the theme directory. You need to use the latest version of theme.", 'stkit' ) . '</div>';
				?>
				<p class="envato-setup-actions step">
					<?php

						if ( !empty( $st_['theme_settings_file'] ) ) { ?>
							<input type="submit" class="button-primary button button-large button-next" value="<?php esc_attr_e( 'Continue', 'stkit' ); ?>" name="save_step" /><?php
						}

						if ( !empty( $st_['theme_settings_file'] ) ) { ?>
							<a href="<?php echo esc_url( $this->get_next_step_link() ); ?>" class="button button-large button-next"><?php esc_attr_e( 'Skip this step', 'stkit' ); ?></a><?php
						}

						wp_nonce_field( 'envato-setup' );

					?>
				</p>
			</form>
			<?php
		}

		public function envato_setup_theme_settings_save() {

			check_admin_referer( 'envato-setup' );

				global
					$st_Options;
					$st_['array'] = array();

					// Get a file
					if ( file_exists( get_stylesheet_directory() . '/demo/theme-settings.txt' ) )
						$st_['theme_settings_file'] = get_stylesheet_directory() . '/demo/theme-settings.txt';

					elseif ( file_exists( get_template_directory() . '/demo/theme-settings.txt' ) )
						$st_['theme_settings_file'] = get_template_directory() . '/demo/theme-settings.txt';

					if ( !empty( $st_['theme_settings_file'] ) ) {

						// Get a content
						$st_['theme_settings'] = file_get_contents( $st_['theme_settings_file'] );
						$st_['array'] = unserialize( base64_decode( wp_filter_nohtml_kses( $st_['theme_settings'] ) ) );
		
						// Update theme settings
						update_option( $st_Options['general']['name'] . 'settings', $st_['array'] );

					}

			wp_redirect( esc_url_raw( $this->get_next_step_link() ) );
			exit;

		}



	/*= 2 ============================================
	
		C O N T E N T   I M P O R T
		Step
	
	===============================================*/

		private function _content_default_get() {

			global
				$st_Options;

			$content = array();

			if ( !empty( $st_Options['global']['demo']['content']['pages'] ) == true ) {
				$content['pages'] = array(
					'title' => esc_attr__( 'Pages', 'stkit' ),
					'description' => esc_attr__( 'Posts, pages, categories, tags, menus, images.', 'stkit' ),
					'pending' => esc_attr__( 'Pending.', 'stkit' ),
					'installing' => esc_attr__( 'Importing dummy content (might take up to 15 min).', 'stkit' ),
					'success' => esc_attr__( 'Success.', 'stkit' ),
					'install_callback' => array( $this,'_content_install_pages' ),
				);
			}
			if ( !empty( $st_Options['global']['demo']['content']['products'] ) == true ) {
				$content['products'] = array(
					'title' => esc_attr__( 'Products', 'stkit' ),
					'description' => esc_attr__( 'Insert default shop products and categories as seen in the demo.', 'stkit' ),
					'pending' => esc_attr__( 'Pending.', 'stkit' ),
					'installing' => esc_attr__( 'Installing.', 'stkit' ),
					'success' => esc_attr__( 'Success.', 'stkit' ),
					'install_callback' => array( $this,'_content_install_products' ),
				);
			}
			if ( !empty( $st_Options['global']['demo']['content']['categories'] ) == true ) {
				$content['categories'] = array(
					'title' => esc_attr__( 'Categories', 'stkit' ),
					'description' => esc_attr__( 'Extra options for categories like on demo.', 'stkit' ),
					'pending' => esc_attr__( 'Pending.', 'stkit' ),
					'installing' => esc_attr__( 'Installing categories.', 'stkit' ),
					'success' => esc_attr__( 'Success.', 'stkit' ),
					'install_callback' => array( $this,'_content_install_category_options' ),
				);
			}
			if ( !empty( $st_Options['global']['demo']['content']['menu'] ) == true ) {
				$content['menu'] = array(
					'title' => esc_attr__( 'Menu', 'stkit' ),
					'description' => esc_attr__( 'Extra options for menu like on demo.', 'stkit' ),
					'pending' => esc_attr__( 'Pending.', 'stkit' ),
					'installing' => esc_attr__( 'Installing menu.', 'stkit' ),
					'success' => esc_attr__( 'Success.', 'stkit' ),
					'install_callback' => array( $this,'_content_install_menu' ),
				);
			}
			if ( !empty( $st_Options['global']['demo']['content']['widgets'] ) == true ) {
				$content['widgets'] = array(
					'title' => esc_attr__( 'Widgets', 'stkit' ),
					'description' => esc_attr__( 'Setup widgets like on demo.', 'stkit' ),
					'pending' => esc_attr__( 'Pending.', 'stkit' ),
					'installing' => esc_attr__( 'Installing widgets.', 'stkit' ),
					'success' => esc_attr__( 'Success.', 'stkit' ),
					'install_callback' => array( $this,'_content_install_widgets' ),
				);
			}
			if ( !empty( $st_Options['global']['demo']['content']['settings'] ) == true ) {
				$content['settings'] = array(
					'title' => esc_attr__( 'Settings', 'stkit' ),
					'description' => esc_attr__( 'Configure other default settings.', 'stkit' ),
					'pending' => esc_attr__( 'Pending.', 'stkit' ),
					'installing' => esc_attr__( 'Installing other settings.', 'stkit' ),
					'success' => esc_attr__( 'Success.', 'stkit' ),
					'install_callback' => array( $this,'_content_install_settings' ),
				);
			}

			return $content;

		}

		/*-------------------------------------------
			Output: Content Import
		-------------------------------------------*/

		public function envato_setup_default_content() {
			?>

				<h1><?php esc_attr_e( 'Default Content', 'stkit' ); ?></h1>

				<form method="post">

					<p><?php printf( esc_attr__( "It's time to insert a default content for your new WordPress website. Choose what you would like inserted below and click Continue.", 'stkit' ), '<a href="' . esc_url( admin_url( 'edit.php?post_type=page' ) ) . '" target="_blank">', '</a>' ); ?></p>

					<table class="envato-setup-pages" cellspacing="0">
						<thead>
						<tr>
							<td class="check"> </td>
							<th class="item"><?php esc_attr_e( 'Item', 'stkit' ); ?></th>
							<th class="description"><?php esc_attr_e( 'Description', 'stkit' ); ?></th>
							<th class="status"><?php esc_attr_e( 'Status', 'stkit' ); ?></th>
						</tr>
						</thead>
						<tbody>
						<?php foreach ( $this->_content_default_get() as $slug => $default ) {  ?>
							<tr class="envato_default_content" data-content="<?php echo esc_attr( $slug );?>">
								<td>
									<input type="checkbox" name="default_content[pages]" class="envato_default_content" id="default_content_<?php echo esc_attr( $slug );?>" value="1" checked>
								</td>
								<td><label for="default_content_<?php echo esc_attr( $slug );?>"><?php echo $default['title']; ?></label></td>
								<td class="description"><?php echo $default['description']; ?></td>
								<td class="status"> <span><?php echo $default['pending'];?></span> <div class="spinner"></div></td>
							</tr>
						<?php } ?>
						</tbody>
					</table>
	
					<p class="envato-setup-actions step">
						<a href="<?php echo esc_url( $this->get_next_step_link() ); ?>" class="button-primary button button-large button-next" data-callback="install_content"><?php esc_attr_e( 'Continue', 'stkit' ); ?></a>
						<a href="<?php echo esc_url( $this->get_next_step_link() ); ?>" class="button button-large button-next"><?php esc_attr_e( 'Skip this step', 'stkit' ); ?></a>
						<?php wp_nonce_field( 'envato-setup' ); ?>
					</p>

				</form>

			<?php
		}


		// AJAX Content
		public function ajax_content() {
			$content = $this->_content_default_get();
			if ( ! check_ajax_referer( 'envato_setup_nonce', 'wpnonce' ) || empty( $_POST['content'] ) && isset( $content[ $_POST['content'] ] ) ) {
				wp_send_json_error( array( 'error' => 1, 'message' => esc_attr__( 'No content Found','stkit' ) ) );
			}

			$json = false;
			$this_content = $content[ $_POST['content'] ];

			if ( isset( $_POST['proceed'] ) ) {

				if ( ! empty( $this_content['install_callback'] ) ) {
					if ( $result = call_user_func( $this_content['install_callback'] ) ) {
						$json = array(
							'done' => 1,
							'message' => $this_content['success'],
							'debug' => $result,
						);
					}
				}
			} else {

				$json = array(
					'url' => admin_url( 'admin-ajax.php' ),
					'action' => 'envato_setup_content',
					'proceed' => 'true',
					'content' => $_POST['content'],
					'_wpnonce' => wp_create_nonce( 'envato_setup_nonce' ),
					'message' => $this_content['installing'],
				);
			}

			if ( $json ) {
				$json['hash'] = md5( serialize( $json ) ); // used for checking if duplicates happen, move to next plugin
				wp_send_json( $json );
			} else {
				wp_send_json( array( 'error' => 1, 'message' => esc_attr__( 'Error','stkit' ) ) );
			}

			exit;

		}

		// Import
		private function _import_wordpress_xml_file( $xml_file_path ) {

			global $wpdb;

			if ( ! defined( 'WP_LOAD_IMPORTERS' ) ) { define( 'WP_LOAD_IMPORTERS', true ); }

			require_once ABSPATH . 'wp-admin/includes/import.php';

			if ( ! class_exists( 'WP_Importer' ) ) {
				$class_wp_importer = ABSPATH . 'wp-admin/includes/class-wp-importer.php';
				if ( file_exists( $class_wp_importer ) ) {
					require $class_wp_importer;
				}
			}

			if ( ! class_exists( 'WP_Import' ) ) {
				$class_wp_importer = __DIR__ .'/importer/wordpress-importer.php';
				if ( file_exists( $class_wp_importer ) ) {
					require $class_wp_importer; }
			}

			if ( class_exists( 'WP_Import' ) ) {
				require_once __DIR__ .'/importer/envato-content-import.php';
				$wp_import = new envato_content_import();
				$wp_import->fetch_attachments = true;
				ob_start();
				$wp_import->import( $xml_file_path );
				$message = ob_get_clean();
				return array( $wp_import->check(),$message );
			}

			return false;

		}

		// Content
		private function _content_install_pages() {

			if ( file_exists( get_stylesheet_directory() . '/demo/whole-content.xml' ) )
				$st_['whole-content'] = get_stylesheet_directory() . '/demo/whole-content.xml';

			elseif ( file_exists( get_template_directory() . '/demo/whole-content.xml' ) )
				$st_['whole-content'] = get_template_directory() . '/demo/whole-content.xml';

			if ( !empty( $st_['whole-content'] ) )
				return $this->_import_wordpress_xml_file( $st_['whole-content'] );

			return false;
		}

		// Category Options
		private function _content_install_category_options() {

			if ( file_exists( get_stylesheet_directory() . '/demo/category-options.txt' ) )
				$import_category_options = get_stylesheet_directory() . '/demo/category-options.txt';

			elseif ( file_exists( get_template_directory() . '/demo/category-options.txt' ) )
				$import_category_options = get_template_directory() . '/demo/category-options.txt';

			if ( $import_category_options ) {
				$import_category_options = file_get_contents( $import_category_options );
				$import_category_options = unserialize( base64_decode( wp_filter_nohtml_kses( $import_category_options ) ) );

				foreach ( $import_category_options as $st_['category'] => $st_['option'] ) {

					if ( !empty( $st_['option']['image'] ) )
						update_option( 'st_category_image_' . $st_['category'], $st_['option']['image'] );

					if ( !empty( $st_['option']['sidebar'] ) )
						update_option( 'st_category_sidebar_' . $st_['category'], $st_['option']['sidebar'] );

				}

			}

			return true;

		}

		// Products
		/*private function _content_install_products() {
			if ( $this->_import_wordpress_xml_file( __DIR__ .'/content/products.xml' ) ) {
				return $this->_import_wordpress_xml_file( __DIR__ .'/content/variations.xml' );
			}
			return false;
		}*/

		// Menus
		private function _get_menu_ids() {
			$menus = get_terms( 'nav_menu' );
			$menu_ids = array();
			foreach ( $menus as $menu ) {
				if ( $menu->name == 'Primary' )
					$menu_ids['menu-1'] = $menu->term_id;
				if ( $menu->name == 'Secondary' )
					$menu_ids['menu-2'] = $menu->term_id;
			}
			return $menu_ids;
		}
		private function _content_install_menu() {
			$menu_ids = $this->_get_menu_ids();
			$save = array();
			if ( isset( $menu_ids['menu-1'] ) ) {
				$save['menu-1'] = $menu_ids['menu-1'];
			}
			if ( isset( $menu_ids['menu-2'] ) ) {
				$save['menu-2'] = $menu_ids['menu-2'];
			}
			if ( $save ) {
				set_theme_mod( 'nav_menu_locations', array_map( 'absint', $save ) );
				return true;
			}
			return false;
		}

		// Widgets
		private function _content_install_widgets() {

			if ( file_exists( get_stylesheet_directory() . '/demo/widget-positions.txt' ) )
				$import_widget_positions = get_stylesheet_directory() . '/demo/widget-positions.txt';

			elseif ( file_exists( get_template_directory() . '/demo/widget-positions.txt' ) )
				$import_widget_positions = get_template_directory() . '/demo/widget-positions.txt';

				$import_widget_positions = file_get_contents( $import_widget_positions );
				$import_widget_positions = unserialize( base64_decode( wp_filter_nohtml_kses( $import_widget_positions ) ) );


			if ( file_exists( get_stylesheet_directory() . '/demo/widget-options.txt' ) )
				$import_widget_options = get_stylesheet_directory() . '/demo/widget-options.txt';

			elseif ( file_exists( get_template_directory() . '/demo/widget-options.txt' ) )
				$import_widget_options = get_template_directory() . '/demo/widget-options.txt';

				$import_widget_options = file_get_contents( $import_widget_options );
				$import_widget_options = unserialize( base64_decode( wp_filter_nohtml_kses( $import_widget_options ) ) );

				// Set an ID for Custom menu
				$menus = get_terms( 'nav_menu' );
				foreach ( $menus as $menu ) {
					if ( $menu->name == 'Custom' || $menu->name == 'Custom menu' ) {
						for ( $x = 0; $x <= 25; $x++ )
							if ( array_key_exists( $x, $import_widget_options['nav_menu'] ) )
								$import_widget_options['nav_menu'][$x]['nav_menu'] = $menu->term_id;
					}
				}

			foreach ( $import_widget_options as $widget_name => $widget_option )
				update_option( 'widget_' . $widget_name, $widget_option );

			update_option( 'sidebars_widgets', $import_widget_positions );

			return true;

		}

		// Other Settings
		private function _content_install_settings() {

			global
				$st_Options;

			// Delete default "Hello World" post
			if ( get_post_status ( 1 ) == 'publish' )
				wp_trash_post( 1 );

			// Set the Shop
			$shoppage = get_page_by_title( 'Shop' );
			if ( $shoppage ) {
				update_option( 'woocommerce_shop_page_id', $shoppage->ID );
			}

			// Set the Frontpage
			if ( !empty( $st_Options['global']['demo']['frontpage'] ) ) {
				$homepage = get_page_by_title( $st_Options['global']['demo']['frontpage'] );
				if ( $homepage ) {
					update_option( 'page_on_front', $homepage->ID );
					update_option( 'show_on_front', 'page' );
				}
			}

			// Set number of posts per page
			if ( !empty( $st_Options['global']['demo']['posts_per_page'] ) ) {
				update_option( 'posts_per_page', $st_Options['global']['demo']['posts_per_page'] );
			}

			// Permalink structure
			//global $wp_rewrite;
			//$wp_rewrite->set_permalink_structure( '/%postname%/' );

			// Other options e.g. for plugins
			foreach ( $st_Options['global']['demo']['options'] as $st_['option'] ) {

				$st_['option_path'] = false;

				if ( file_exists( get_stylesheet_directory() . '/demo/option-' . $st_['option'] . '.txt' ) )
					$st_['option_path'] = get_stylesheet_directory() . '/demo/option-' . $st_['option'] . '.txt';
	
				elseif ( file_exists( get_template_directory() . '/demo/option-' . $st_['option'] . '.txt' ) )
					$st_['option_path'] = get_stylesheet_directory() . '/demo/option-' . $st_['option'] . '.txt';

				if ( $st_['option_path'] ) {

					$st_['option_value'] = file_get_contents( $st_['option_path'] );
					$st_['option_value'] = unserialize( base64_decode( wp_filter_nohtml_kses( $st_['option_value'] ) ) );

					update_option( $st_['option'], $st_['option_value'] );

				}

			}

			return true;
		}



	/*= 3 ============================================
	
		A S S I S T A N C E
		Step
	
	===============================================*/

		public function envato_setup_help_support() {

			global
				$st_Options;

			?>
				<h1>Assistance</h1>
	
				<h3>License</h3>
				<p>This license allows you to use this theme on a single website. Please <a href="http://strictthemes.com/to/<?php echo esc_html( $st_Options['general']['label'] ) ?>">purchase an additional license</a> to use this theme on another website.</p>
	
				<h3>Support</h3>
				<p>This theme comes with 6 months item support from purchase date <em>(with the option to extend this period)</em>. This license allows you to use this theme on a single website. Item Support can be accessed from the <a href="http://strictthemes.com/to/<?php echo esc_html( $st_Options['general']['label'] ) ?>" target="_blank">comments section</a>. See also <a href="http://themeforest.net/page/item_support_policy" target="_blank">Item Support Policy</a>.</p>
	
				<p class="envato-setup-actions step">
					<a href="<?php echo esc_url( $this->get_next_step_link() ); ?>" class="button button-primary button-large button-next"><?php esc_attr_e( 'Agree and Continue', 'stkit' ); ?></a>
					<?php wp_nonce_field( 'envato-setup' ); ?>
				</p>
			<?php
		}



	/*= 4 ============================================
	
		R E A D Y
		Step
	
	===============================================*/

		public function envato_setup_ready() {

			global
				$st_Options;

			?>
			<h1>
				<?php esc_attr_e( 'Your Website is Ready!', 'stkit' ); ?>
				<a href="https://twitter.com/share" class="twitter-share-button" data-url="http://strictthemes.com/to/portfolio" data-text="<?php echo esc_attr( 'I just installed the ' . $st_Options['general']['label'] . ' #WordPress theme from #ThemeForest' ); ?>" data-via="StrictThemes" data-size="large"></a>
			</h1>
			<script>!function(d,s,id){var js,fjs=d.getElementsByTagName(s)[0];if (!d.getElementById(id)){js=d.createElement(s);js.id=id;js.src="//platform.twitter.com/widgets.js";fjs.parentNode.insertBefore(js,fjs);}}(document,"script","twitter-wjs");</script>
			<p>Congratulations! The theme has been activated and your website is ready. Login to your WordPress dashboard to modify the default content to suit your needs.</p>
			<p class="st-button-finish"><a class="button button-hero" href="<?php echo esc_url( home_url() ); ?>" target="_blank"><?php esc_attr_e( 'View your new website!', 'stkit' ); ?></a></p>

			<div class="envato-setup-next-steps">
				<div class="envato-setup-next-steps-first">
					<?php //!empty( $st_Options['global']['demo']['learnmore'] ) == true ) { // Not using because of Truemag, Grimag ?>
					<?php if ( !isset( $st_Options['global']['demo']['learnmore'] ) || !empty( $st_Options['general']['label'] ) != 'GuruBlog' ) { ?>
						<h2><?php esc_attr_e( 'Learn How To:', 'stkit' ); ?></h2>
						<ul id="kit-learn-more">
							<li><a class="welcome-icon dashicons-welcome-learn-more" target="_blank" href="http://click.linksynergy.com/fs-bin/click?id=5SjWahTy1L8&subid=&offerid=323058.1&type=10&tmpid=14538&RD_PARM1=https%3A%2F%2Fwww.udemy.com%2F30-days-blogging%2F">30-Day Step-By-Step Guide to Successful Blogging</a></li>
							<li><a class="welcome-icon dashicons-welcome-learn-more" target="_blank" href="http://click.linksynergy.com/fs-bin/click?id=5SjWahTy1L8&subid=&offerid=323058.1&type=10&tmpid=14538&RD_PARM1=https%3A%2F%2Fwww.udemy.com%2Fblog-organic-traffic%2F">Blogging For Business: 3x Traffic Without Ads</a></li>
							<li><a class="welcome-icon dashicons-welcome-learn-more" target="_blank" href="http://click.linksynergy.com/fs-bin/click?id=5SjWahTy1L8&subid=&offerid=323058.1&type=10&tmpid=14538&RD_PARM1=https%3A%2F%2Fwww.udemy.com%2Femergency-fast-cash-generators%2F">Emergency Fast Cash Generators</a></li>
							<li><a class="welcome-icon dashicons-welcome-learn-more" target="_blank" href="http://click.linksynergy.com/fs-bin/click?id=5SjWahTy1L8&subid=&offerid=323058.1&type=10&tmpid=14538&RD_PARM1=https%3A%2F%2Fwww.udemy.com%2Fgoogleadsense%2F">Google AdSense: A Complete PPC Passive Income Course</a></li>
							<li><a class="welcome-icon dashicons-welcome-learn-more" target="_blank" href="http://click.linksynergy.com/fs-bin/click?id=5SjWahTy1L8&subid=&offerid=323058.1&type=10&tmpid=14538&RD_PARM1=https%3A%2F%2Fwww.udemy.com%2Fcopy-paste-profits%2F">Copy & Paste To Make Money Online (Solo Ad Business)</a></li>
							<li><a class="welcome-icon dashicons-welcome-learn-more" target="_blank" href="http://click.linksynergy.com/fs-bin/click?id=5SjWahTy1L8&subid=&offerid=323058.1&type=10&tmpid=14538&RD_PARM1=https%3A%2F%2Fwww.udemy.com%2Fmultiply-earning-with-adsense-seo-wordpress-and-blogger%2F">Complete SEO Rank #1 on Google + Wordpress + Adsense Earning</a></li>
							<li><a class="welcome-icon dashicons-welcome-learn-more" target="_blank" href="http://click.linksynergy.com/fs-bin/click?id=5SjWahTy1L8&subid=&offerid=323058.1&type=10&tmpid=14538&RD_PARM1=https%3A%2F%2Fwww.udemy.com%2Frun-a-google-adsense-publishing-business-from-anywhere%2F">Run a Google Adsense publishing business from anywhere</a></li>
							<li><a class="welcome-icon dashicons-welcome-learn-more" target="_blank" href="http://click.linksynergy.com/fs-bin/click?id=5SjWahTy1L8&subid=&offerid=323058.1&type=10&tmpid=14538&RD_PARM1=https%3A%2F%2Fwww.udemy.com%2Faffiliate-marketing-affiliate-marketing-facebook-with-cpa%2F">How To Make Money With Facebook and CPA Can Make Money Fast?</a></li>
							<li><a class="welcome-icon dashicons-welcome-learn-more" target="_blank" href="http://click.linksynergy.com/fs-bin/click?id=5SjWahTy1L8&subid=&offerid=323058.1&type=10&tmpid=14538&RD_PARM1=https%3A%2F%2Fwww.udemy.com%2Fmake-money-online-with-blog-secret-easy-fast-blogging-method%2F">Make Money Online From Blogging - FAST Blogging Method</a></li>
						</ul>
						<a id="kit-learn-more-button" href="#" class="button">Show all</a>
						<script type="text/javascript">
							var stMore = jQuery.noConflict();
							jQuery(document).ready(function() {
								'use strict';
								stMore('#kit-learn-more-button').click(function(){
									stMore('#kit-learn-more').addClass('opened');
									stMore(this).remove();
									return false;
								});
							})
						</script>
					<?php } ?>
				</div>
				<div class="envato-setup-next-steps-last">
					<h2><?php esc_attr_e( 'Do not forget to:', 'stkit' ); ?></h2>
					<ul>
						<li><a class="welcome-icon dashicons-facebook" target="_blank" href="https://www.facebook.com/StrictThemes"><?php esc_html_e( 'Follow Us', 'stkit' ) ?></a></li>
						<li><a class="welcome-icon dashicons-smiley" target="_blank" href="http://themeforest.net/downloads"><?php esc_html_e( 'Rate The Theme', 'stkit' ); ?></a></li>
						<li><a class="welcome-icon dashicons-cart" target="_blank" href="http://strictthemes.com/to/<?php echo esc_html( $st_Options['general']['label'] ) ?>"><?php esc_html_e( 'Buy Another One', 'stkit' ); ?></a></li>
					</ul>
				</div>
			</div>
			<?php
		}

		public function is_submenu_page() {
			return ( $this->parent_slug == '' ) ? false : true;
		}
	}

}

// Activate Setup Wizard
if ( ! function_exists( 'envato_theme_setup_wizard' ) ) {
	function envato_theme_setup_wizard() {
		Envato_Theme_Setup_Wizard::get_instance();
	}
}
add_action( 'after_setup_theme', 'envato_theme_setup_wizard', 10 );

// Disable BuddyPress redirect after plugin activation
function st_bp_remove_activation_redirect() {
	delete_transient( '_bp_is_new_install' );
	delete_transient( '_bp_activation_redirect' );
}
add_action( 'bp_activation', 'st_bp_remove_activation_redirect', 99 );

// Disable bbPress redirect after plugin activation
remove_action( 'bbp_admin_init', 'bbp_do_activation_redirect', 1 );

// Disable WooCommerce redirect after plugin activation
function st_wc_remove_activation_redirect() {
	if ( get_transient( '_wc_activation_redirect' ) ) {
		delete_transient( '_wc_activation_redirect' );
		WC_Admin_Notices::remove_notice( 'install' );
	}
}
add_action( 'before_woocommerce_init', 'st_wc_remove_activation_redirect', 99 );