<?php if ( !defined( 'ABSPATH' ) ) exit;

/*

	version 1.0

*/

class ST_Kit_Widget_Categories extends WP_Widget {

	public function __construct() {
		$widget_ops = array( 'classname' => 'widget_st_kit_widget_categories', 'description' => esc_attr__( 'Display a list of categories.', 'stkit' ) );
		$control_ops = array( 'width' => 250, 'height' => 250 );
		parent::__construct( 'st_kit_widget_categories', esc_attr__( 'ST Categories', 'stkit' ), $widget_ops, $control_ops );
	}



	/*===============================================

		F R O N T - E N D
		Widget

	===============================================*/

	public function widget( $args, $instance ) {

		if ( empty( $instance['multiple-categories'] ) ) {
			return; }

		global
			$st_Settings;

		echo $args['before_widget'];

			$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );
			$text = apply_filters( 'widget_text', empty( $instance['fallback-text'] ) ? '' : $instance['fallback-text'], $instance );

			if ( !empty( $title ) ) {
				echo $args['before_title'] . $title . $args['after_title']; }

			echo '<div class="st-feat-catwidget">';

				foreach ( $instance['multiple-categories'] as $st_['value'] ) {

					// Get category data
					$st_['cat'] = get_term_by( 'id', $st_['value'], 'category' );

					// Thumb
					if ( is_object( $st_['cat'] ) ) {
						$st_['size'] = 300;
						$st_['att_id'] = get_option( 'st_category_image_' . $st_['cat']->term_id );
						if ( $st_['att_id'] ) {
							$st_['thumb'] = wp_get_attachment_image_src( $st_['att_id'], array( $st_['size'], $st_['size'] ) );
							$st_['thumb-2x'] = !empty( $st_Settings['hidpi'] ) != 'no' ? wp_get_attachment_image_src( $st_['att_id'], array( $st_['size'] * 2, $st_['size'] * 2 ) ) : '';
							$st_['is_thumb'] = true;
						}
						else {
							$st_['thumb'] = 'none';
							$st_['is_thumb'] = false;
						}

						// Define classes
						$st_['class'] = $st_['is_thumb'] ? 'st-feat-cat st-feat-cat-yes-thumb' : 'st-feat-cat st-feat-cat-no-thumb'; ?>

						<a class="<?php echo $st_['class'] ?>" href="<?php echo esc_url( get_category_link( $st_['cat']->term_id ) ) ?>" data-label="<?php echo $st_['cat']->name ?>" data-count="<?php echo $st_['cat']->count ?>">
							<?php
								if ( $st_['is_thumb'] ) {
									echo '<img src="' . $st_['thumb'][0] . '" srcset="' . $st_['thumb'][0] . ' 1x, ' . $st_['thumb-2x'][0] . ' 2x" alt="' . $st_['cat']->name . '" />'; }
							?>
						</a><?php
					}

				}

			echo '</div>';

		echo $args['after_widget'];

	}



	/*===============================================

		U P D A T E
		Sanitize widget form values as they are saved

	===============================================*/

	public function update( $new_instance, $old_instance ) {

		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['multiple-categories'] = $new_instance['multiple-categories'];

		return $instance;

	}



	/*===============================================

		B A C K - E N D
		Controls

	===============================================*/

	public function form( $instance ) {

		$instance = wp_parse_args( (array) $instance, array(
			'title'					=> '',
			'multiple-categories'	=> '',
			)
		);

		$st_['title'] = strip_tags( $instance['title'] );
		$st_['multiple-categories'] = isset( $instance['multiple-categories'] ) ? $instance['multiple-categories'] : array();
        $st_['categories'] = get_categories();

		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_attr_e( 'Title:' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $st_['title'] ); ?>">
		</p>

		<p id="st-sw-categories">
			<select multiple="multiple" name="<?php echo $this->get_field_name( 'multiple-categories' ) ?>[]" class="widefat">
				<?php

					foreach( $st_['categories'] as $st_['category'] ) {

						$st_['selected'] = '';

						foreach( (array)$st_['multiple-categories'] as $st_['value'] )
							if ( $st_['category']->term_id == $st_['value'] )
								$st_['selected'] = ' selected';

						echo '<option value="' . $st_['category']->term_id . '"' . $st_['selected'] . '>' . $st_['category']->name . '</option>';

					}

				?>
			</select>
		</p>

		<?php
	}



} // class ST_Kit_Widget_Categories

function st_kit_widget_categories_init() {

	register_widget('ST_Kit_Widget_Categories');

	//do_action( 'widgets_init' );

}
add_action( 'widgets_init', 'st_kit_widget_categories_init', 1 );


?>
