<?php if ( !defined( 'ABSPATH' ) ) exit;

/*

	version 2.0

*/

class ST_Kit_Widget_Posts extends WP_Widget {

	public function __construct() {
		$widget_ops = array( 'classname' => 'widget_st_kit_widget_posts', 'description' => esc_attr__( 'Display a recent, random or popular posts with thumbnails and excerpts.', 'stkit' ) );
		$control_ops = array( 'width' => 250, 'height' => 250 );
		parent::__construct( 'st_kit_widget_posts', esc_attr__( 'ST Posts', 'stkit' ), $widget_ops, $control_ops );
	}



	/*===============================================
	
		F R O N T - E N D
		Widget
	
	===============================================*/

	public function widget( $args, $instance ) {

		global
			$st_Options,
			$st_Settings;

		if ( !isset( $widget_number ) )
			$widget_number = $this->id;

		$title = !empty( $instance['title'] ) ? $instance['title'] : '';
		$post_type = !empty( $instance['post_type'] ) ? $instance['post_type'] : 'post';
		$format = !empty( $instance['format'] ) ? $instance['format'] : '';
		$type = !empty( $instance['type'] ) ? $instance['type'] : 'recent';
		$timeframe = !empty( $instance['timeframe'] ) ? $instance['timeframe'] : 'all';
		$cats = !empty( $instance['cats'] ) ? $instance['cats'] : '';
		//$cats = preg_split("/[\s,]+/", $vars['cats']); // array
		$qty = $instance['qty'];
		$thumb = !empty( $instance['thumb'] ) ? $instance['thumb'] : '';
		$date = !empty( $instance['date'] ) ? $instance['date'] : '';
		$excerpt = !empty( $instance['excerpt'] ) ? $instance['excerpt'] : '';
		$cache = !empty( $instance['cache'] ) ? $instance['cache'] : '';
		$widget_class = str_replace( '_', '-', $type );

		// Taxonomy
		if ( $post_type == 'post' )
			$taxonomy = 'category_name';
		else
			$taxonomy = !empty( $st_Settings['ctp_category'] ) ? $st_Settings['ctp_category'] : $st_Options['ctp']['category'];

		$args_query = array();

		// Recent posts
		if ( $type == 'recent' ) {

			 $args_query = array(
				'post_type'				=> $post_type,
				'posts_per_page'		=> $qty,
				'orderby'				=> 'date',
				'order'					=> 'DESC',
				'post_status'			=> 'publish',
				'ignore_sticky_posts'	=> 1,
				$taxonomy				=> $cats
				);

		}

		// Random posts
		elseif ( $type == 'random' ) {

			 $args_query = array(
				'post_type'				=> $post_type,
				'posts_per_page'		=> $qty,
				'orderby'				=> 'rand',
				'post_status'			=> 'publish',
				'ignore_sticky_posts'	=> 1,
				'date_query'			=> ( $timeframe != 'all' ? 
													array(
														array(
															'column'	=> 'post_date_gmt',
															'after'		=> '1 ' . $timeframe . ' ago',
														),
													)
											: '' ),
				$taxonomy				=> $cats,
				);

		}

		// Most viewed posts
		elseif ( $type == 'most_viewed' ) {

			$args_query = array (
				'post_type'				=> $post_type,
				'posts_per_page'		=> $qty,
				'ignore_sticky_posts'	=> 1,
				'orderby'				=> 'meta_value_num',
				'meta_key'				=> 'post_views_count',
				'date_query'			=> ( $timeframe != 'all' ? 
													array(
														array(
															'column'	=> 'post_date_gmt',
															'after'		=> '1 ' . $timeframe . ' ago',
														),
													)
											: '' ),
				$taxonomy				=> $cats,
			);

		}

		// Most commented posts
		elseif ( $type == 'most_commented' ) {

			 $args_query = array(
				'post_type'				=> $post_type,
				'posts_per_page'		=> $qty,
				'orderby'				=> 'comment_count',
				'order'					=> 'DESC',
				'post_status'			=> 'publish',
				'ignore_sticky_posts'	=> 1,
				'date_query'			=> ( $timeframe != 'all' ? 
													array(
														array(
															'column'	=> 'post_date_gmt',
															'after'		=> '1 ' . $timeframe . ' ago',
														),
													)
											: '' ),
				$taxonomy				=> $cats,
			);

		}

		$kit_query = null;

		if ( !empty( $cache ) )
			$kit_query = get_transient( 'st_posts_widget_' . $widget_number );

		if ( $kit_query == false ) {

			$kit_query = new WP_Query( $args_query );

			set_transient( 'st_posts_widget_' . $widget_number, $kit_query, 60 * 60 * 12 );

		}

			// Make a custom $args['before_widget']
			$args['before_widget'] = str_replace( 'widget', 'widget widget-posts widget-posts-' . $widget_class, $args['before_widget'] );
			echo $args['before_widget'];

			// Output
			if ( !empty( $instance['title'] ) ) {
				echo $args['before_title'] . $instance['title'] . $args['after_title']; }

			$count = 0;

			while ( $kit_query->have_posts() ) : $kit_query->the_post();

				$count++;
				$class = '';

				if ( $count == 2 ) {
					$class = ' class="even"';
					$count = 0;
				}

				echo "\n";

				echo '<div' . $class . '>';



					// Thumbnail
					if ( $thumb == 'display' ) {

						if ( has_post_thumbnail() ) {
					
							$image = get_the_post_thumbnail( $kit_query->post->ID, ( !empty( $st_Options['global']['images']['thumbnail'] ) ? 'thumbnail' : ( !empty( $st_Options['general']['prefix'] ) ? $st_Options['general']['prefix'] . 'thumbnail' : 'st-thumbnail' ) ) ); // st-thumbnail since v.1.7.6
							$class = 'widget-posts-image';
					
						}
					
						else {

							if ( !empty( $st_Options['font-st'] ) == true ) {

								$image = '';
								$class = 'widget-posts-icon ico-st ico-' . st_get_format_icon( $kit_query->post->ID, false, false, false, 'text' );

							}

							else {

								$image = st_get_format_icon( $kit_query->post->ID, 16 );
								$class = 'widget-posts-icon';

							}
					
						}

						echo '<a class="' . $class . '" href="' . get_permalink() . '">' . $image . '</a>';

					}


					// Widget box
					$class = $thumb == 'display' ? ' widget-posts-post-box-with-thumb' : '';

					echo '<div class="widget-posts-post-box' . $class . '">';


						// Title
						if ( get_the_title( $kit_query->post->ID ) ) {

							$st_['subtitle'] = !empty( $st_Options['widgets']['recent-posts-subtitle'] ) ? get_post_meta( $kit_query->post->ID, 'subtitle_value', true ) : '';

							echo '<a class="widget-posts-title" href="' . get_permalink( $kit_query->post->ID ) . '">' . esc_attr( get_the_title( $kit_query->post->ID ) ) . ( $st_['subtitle'] ? ' <span>' . esc_attr( $st_['subtitle'] ) . '</span>' : '' ) . '</a>';

						}

						// Date
						if ( $date == 'display' ) {

							if ( !empty( $st_Settings['nice_time'] ) && $st_Settings['nice_time'] == 'yes' ) {
								echo '<div class="widget-posts-date">' . st_nicetime( $kit_query->post->post_date_gmt ) . '</div>';
							}
							else {
								echo '<div class="widget-posts-date">' . get_the_time( get_option('date_format'), $kit_query->post->ID ) . '</div>';
							}

						}


						// Number of comments
						if ( $type == 'most_commented' && get_comments_number( $kit_query->post->ID ) != 0 ) {

							echo '<div class="widget-posts-comments">';

								comments_number( esc_attr__( 'No Comments', 'stkit' ), esc_attr__( '1 Comment', 'stkit' ), esc_attr__( '% Comments', 'stkit' ));

							echo '</div>';

						}


						// Number of views
						if ( $type == 'most_viewed' ) {

							echo '<div class="widget-posts-views">';

								echo number_format( get_post_meta( $kit_query->post->ID, 'post_views_count', true ) ) . ' <span>' . esc_attr__( 'views', 'stkit' ) . '</span>';

							echo '</div>';

						}


						// Excerpt
						if ( $excerpt == 'display' )
							echo '<div class="widget-posts-excerpt">' . wpautop( esc_attr( get_the_excerpt() ) ) . '</div>';


					echo '</div>';

				echo '<div class="clear"><!-- --></div></div>';

			endwhile;
	
		wp_reset_postdata();

		echo $args['after_widget'];

	}



	/*===============================================
	
		U P D A T E
		Sanitize widget form values as they are saved
	
	===============================================*/

	public function update( $new_instance, $old_instance ) {

		$instance = $old_instance;
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['post_type'] = strip_tags( $new_instance['post_type'] );
		$instance['format'] = strip_tags( $new_instance['format'] );
		$instance['type'] = strip_tags( $new_instance['type'] );
		$instance['timeframe'] = strip_tags( $new_instance['timeframe'] );
		$instance['cats'] = strip_tags( $new_instance['cats'] );
		$instance['qty'] = strip_tags( $new_instance['qty'] );
		$instance['thumb'] = strip_tags( $new_instance['thumb'] );
		$instance['date'] = strip_tags( $new_instance['date'] );
		$instance['excerpt'] = strip_tags( $new_instance['excerpt'] );
		$instance['cache'] = strip_tags( $new_instance['cache'] );

		return $instance;

	}



	/*===============================================
	
		B A C K - E N D
		Controls
	
	===============================================*/

	public function form( $instance ) {

		$instance = wp_parse_args( (array) $instance, array(
			'title'					=> '',
			'post_type'				=> '',
			'format'				=> '',
			'type'					=> '',
			'timeframe'				=> '',
			'cats'					=> '',
			'qty'					=> '',
			'thumb'					=> '',
			'date'					=> '',
			'excerpt'				=> '',
			'cache'					=> '',
			)
		);

		global
			$st_Options,
			$st_Settings;

		// Vars
		$title = strip_tags( $instance['title'] );
		$post_type = strip_tags( $instance['post_type'] );
		$format = strip_tags( $instance['format'] );
		$type = strip_tags( $instance['type'] );
		$timeframe = strip_tags( $instance['timeframe'] );
		$cats = strip_tags( $instance['cats'] );
		$qty = strip_tags( $instance['qty'] );
		$thumb = strip_tags( $instance['thumb'] );
		$date = strip_tags( $instance['date'] );
		$excerpt = strip_tags( $instance['excerpt'] );
		$cache = strip_tags( $instance['cache'] );

		// Post type names
		$st_['st_post'] = !empty( $st_Settings['ctp_post'] ) ? $st_Settings['ctp_post'] : $st_Options['ctp']['post'];

		?>


		<fieldset class="panel-fieldset metabox-fieldset">
			<legend><?php esc_attr_e( 'Title', 'stkit' ) ?></legend>

			<input type="text" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $title; ?>" />
			<small><?php esc_attr_e( 'Widget title.', 'stkit' ); ?></small>

			<div class="clear"><!-- --></div>
		</fieldset>
	
		<fieldset class="panel-fieldset metabox-fieldset"><legend><?php esc_attr_e( 'Posts', 'stkit' ) ?></legend>

			<?php

				if ( !empty( $st_Settings['projects_status'] ) && $st_Settings['projects_status'] == 'yes' ) { ?>

					<label><input type="radio" value="post" name="<?php echo $this->get_field_name( 'post_type' ); ?>"
						<?php if ( !$post_type || $post_type == 'post' ) echo 'checked="checked"'; ?> /><?php esc_attr_e( 'Posts', 'stkit' ) ?></label>
	
					<label><input type="radio" value="<?php echo $st_['st_post'] ?>" name="<?php echo $this->get_field_name( 'post_type' ); ?>"
						<?php if ( $post_type == $st_['st_post'] ) echo 'checked="checked"'; ?> /><?php esc_attr_e( 'Projects', 'stkit' ) ?></label>
	
					<p><small><?php esc_attr_e( 'Select a type of posts.', 'stkit' ); ?></small></p>
	
	
					<div class="clear"><!-- --></div><?php

				}

				// Format
				/*if ( $st_Options['global']['post-formats']['enabled'] ) { ?>

					<select name="<?php echo $prefix . '[' . $number; ?>][format]">
						<option value="all" <?php if ( $format == 'all' ) echo 'selected'; ?>><?php esc_attr_e( 'All', 'stkit' ); ?></option>
						<?php
		
							foreach ( $st_Options['global']['post-formats'] as $value ) {

								if ( $value['status'] ) {
		
									$out = '<option value="' . $value['label'] . '"';
			
									if ( $format == $value['label'] )
										$out .= ' selected';
			
									$out .= '>' . $value['label'] . '</option>';
			
									echo $out;

								}
		
							}
		
						?>
					</select>
					<p><small><?php esc_attr_e( 'Select a format of posts.', 'stkit' ); ?></small></p>
					<div class="clear"><!-- --></div><?php

				}*/

			?>

			<select name="<?php echo $this->get_field_name( 'type' ); ?>">
				<option value="recent" <?php if ( $type == 'recent' ) echo 'selected'; ?>><?php esc_attr_e( 'Recent', 'stkit' ); ?></option>
				<option value="random" <?php if ( $type == 'random' ) echo 'selected'; ?>><?php esc_attr_e( 'Random', 'stkit' ); ?></option>
				<option value="most_viewed" <?php if ( $type == 'most_viewed' ) echo 'selected'; if ( empty( $st_Settings['post_views'] ) || $st_Settings['post_views'] != 'yes' ) echo 'disabled'; ?>><?php esc_attr_e( 'Most viewed', 'stkit' ); ?></option>
				<option value="most_commented" <?php if ( $type == 'most_commented' ) echo 'selected'; ?>><?php esc_attr_e( 'Most commented', 'stkit' ); ?></option>
			</select>
			<p>
				<small><?php esc_attr_e( 'Select a kind of posts.', 'stkit' ) ?></small>
				<?php
					if (
						empty( $st_Settings['post_views'] ) ||
						!empty( $st_Settings['post_views'] ) && $st_Settings['post_views'] != 'yes' )
							echo '<small>' . esc_attr__( "Checkbox <a href='admin.php?page=st-major-settings'>Post Views</a> in case you'd like to show a most viewed posts.", 'stkit' ) . '</small>';
				?>
			</p>


			<div class="clear"><!-- --></div>


			<select name="<?php echo $this->get_field_name( 'timeframe' ); ?>">
				<option value="all" <?php if ( $timeframe == 'all' ) echo 'selected'; ?>><?php esc_attr_e( 'For all time', 'stkit' ); ?></option>
				<option value="year" <?php if ( $timeframe == 'year' ) echo 'selected'; ?>><?php esc_attr_e( 'For last year', 'stkit' ); ?></option>
				<option value="month" <?php if ( $timeframe == 'month' ) echo 'selected'; ?>><?php esc_attr_e( 'For last month', 'stkit' ); ?></option>
				<option value="week" <?php if ( $timeframe == 'week' ) echo 'selected'; ?>><?php esc_attr_e( 'For last week', 'stkit' ); ?></option>
			</select>
			<p>
				<small><?php esc_attr_e( 'Select a time frame.', 'stkit' ) ?></small>
			</p>


			<div class="clear"><!-- --></div>


			<input type="text" name="<?php echo $this->get_field_name( 'cats' ); ?>" value="<?php echo $cats; ?>" />
			<p><small><?php esc_attr_e( 'Enter a slugs of categories separated by comma. Optional.', 'stkit' ); ?></small></p>


			<div class="clear"><!-- --></div>


			<select name="<?php echo $this->get_field_name( 'qty' ); ?>">
				<?php

					$arr = array(1,2,3,5,7,10,15);

					foreach ( $arr as $value ) {

						$out = '<option value="' . $value . '"';

						if ( $qty == $value )
							$out .= ' selected';

						$out .= '>' . $value . '</option>';

						echo $out;


					}

				?>
			</select>
			<p><small><?php esc_attr_e( 'Select a number of posts.', 'stkit' ); ?></small></p>


			<div class="clear"><!-- --></div>


			<label><input type="checkbox" name="<?php echo $this->get_field_name( 'thumb' ); ?>" value="display" <?php if ( $thumb == 'display' ) echo 'checked'; ?> /><?php esc_attr_e( 'Thumbnail', 'stkit' ) ?></label>


			<div class="clear"><!-- --></div>


			<label><input type="checkbox" name="<?php echo $this->get_field_name( 'date' ); ?>" value="display" <?php if ( $date == 'display' ) echo 'checked'; ?> /><?php esc_attr_e( 'Date', 'stkit' ) ?></label>


			<div class="clear"><!-- --></div>


			<label><input type="checkbox" name="<?php echo $this->get_field_name( 'excerpt' ); ?>" value="display" <?php if ( $excerpt == 'display' ) echo 'checked'; ?> /><?php esc_attr_e( 'Excerpt', 'stkit' ) ?></label>


			<div class="clear"><!-- --></div>

		</fieldset>

		<fieldset class="panel-fieldset metabox-fieldset">
			<legend><?php esc_attr_e( 'Misc', 'stkit' ) ?></legend>

			<label><input type="checkbox" name="<?php echo $this->get_field_name( 'cache' ); ?>" value="display" <?php if ( $cache == 'display' ) echo 'checked'; ?> /><?php esc_attr_e( 'Cache', 'stkit' ) ?></label>
			<small><?php esc_attr_e( 'Store a query result within 12 hours. Recommended.', 'stkit' ); ?></small>

			<div class="clear"><!-- --></div>
		</fieldset>

		<?php
	}



} // class ST_Kit_Widget_Posts

function st_kit_widget_posts_init() {

	register_widget('ST_Kit_Widget_Posts');

	//do_action( 'widgets_init' );

}
add_action( 'widgets_init', 'st_kit_widget_posts_init', 1 );


?>